==> moodle-1.4.5.tgz: moodle/lang/cs/exercise.php <==
<?PHP // $Id: exercise.php,v 1.1.8.2 2004/12/17 15:59:29 moodler Exp $ 
      // exercise.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004100800)


$string['absent'] = 'Chyb';
$string['accumulative'] = 'Nahromadn';
$string['action'] = 'Akce';
$string['ago'] = 'Ped $a';
$string['amend'] = 'Doplte';
$string['amendassessmentelements'] = 'Doplte poloky hodnocen';
$string['amendtitle'] = 'Doplte ';
$string['analysis'] = 'Rozbor';
$string['assess'] = 'Hodnotit';
$string['assessed'] = 'Hodnoceno';
$string['assessment'] = 'Hodnocen';
$string['assessmentby'] = 'Hodnoceno - $a';
$string['assessmentform'] = 'Hodnotc formul';
$string['assessmentmadebythe'] = 'Hodnocen provedl(a) $a';
$string['assessmentofthissubmission'] = 'Hodnocen tohoto odevzdanho kolu';
$string['assessments'] = 'Hodnocen';
$string['atthisstageyou'] = 'V tomto stdiu jste dokonili hodnocen.<br />
Na jeho zklad mete chtt svoji prci pepracovat.<br /> 
Pokud tak udlte, nezapomete tak upravit sv hodnocen.<br /> 
To mete provst kliknutm na odkaz Pehodnotit uveden ne.';
$string['awaitingassessmentbythe'] = 'ek se na hodnocen od $a';
$string['clearlateflag'] = 'Smazat pznak Zpodno';
$string['comment'] = 'Koment';
$string['comparisonofassessments'] = 'Srovnn hodnocen';
$string['confirmdeletionofthisitem'] = 'Potvrte odstrann tohoto $a';
$string['correct'] = 'Opravte';
$string['count'] = 'Poet';
$string['criterion'] = 'Kritrium';
$string['deadline'] = 'Uzvrka';
$string['deadlineis'] = 'Uzvrka je $a';
$string['delete'] = 'Odstranit';
$string['deletesubmissionwarning'] = 'Upozornn: toto een je ji hodnoceno ($a-krt).<br />Rozhodn vm jej doporuujeme NEODSTRAOVAT. ';
$string['deleting'] = 'Odstrauje se';
$string['description'] = 'Popis';
$string['descriptionofexercise'] = 'Pi zadvn kolu je popis cvien
nebo lohy, kter maj $a splnit, zadn ve Wordovskm dokumentu 
nebo HTML souboru. Tento soubor se zkopruje do cvien dve, ne maj
$a cvien zpstupnno. Je tak mono vytvoit sadu variant tho cvien 
nebo lohy, opt ve Wordu nebo v HTML a zkoprovat je do cvien pedtm, ne 
ho budou mt $a zpstupnno.';
$string['detailsofassessment'] = 'Podrobnosti hodnocen';
$string['displayoffinalgrades'] = 'Zobrazen konenho potu bod';
$string['doubleupload'] = 'Varovn: toto een bylo pravdpodobn poslno
dvakrt. Bte na strnku Sprvy a zjistte, zda tento uivatel
podal dv een v krtkm asovm intervalu. Dve ne budete pokraovat,
vymate jedno z tchto een.';
$string['duedate'] = 'Datum uzvrky';
$string['edit'] = 'Upravit';
$string['editingassessmentelements'] = 'prava poloek hodnocen';
$string['element'] = 'Poloka';
$string['elementweight'] = 'Vha poloky';
$string['enterpassword'] = 'Vlote heslo';
$string['entriessaved'] = 'Zznamy uloeny';
$string['errorbanded'] = 'Mnostv chyb';
$string['excellent'] = 'Vborn';
$string['exerciseassessments'] = 'Hodnocen cvien';
$string['exercisefeedback'] = 'Cvien - zptn vazba';
$string['exercisesubmissions'] = 'een';
$string['fair'] = 'Uspokojiv';
$string['generalcomment'] = 'Obecn koment';
$string['good'] = 'Dobr';
$string['gradeassessment'] = 'Bodov ohodnocen';
$string['gradeforassessment'] = 'Body pro hodnocen';
$string['gradeforstudentsassessment'] = 'Body za hodnocen, kter dlaj $a';
$string['gradeforsubmission'] = 'Body za een';
$string['gradetable'] = 'Bodov tabulka';
$string['gradinggrade'] = 'Body za bodovn';
$string['gradingstrategy'] = 'Bodovac strategie';
$string['handlingofmultiplesubmissions'] = 'Zpracovn vce een';
$string['hidenamesfromstudents'] = 'Skrt jmna ped studenty';
$string['incorrect'] = 'Nesprvn';
$string['late'] = 'Pozd';
$string['lax'] = 'Nedbal';
$string['leaguetable'] = 'Ligov tabulka odevzdanch prac';
$string['mail1'] = 'Vas ukol \'$a\' hodnotil ';
$string['mail2'] = 'Poznamky a body lze videt v zadani cviceni \'$a\'';
$string['mail3'] = 'Muzete jej videt v zadani ukolu vaseho cviceni';
$string['mail6'] = 'Vase hodnoceni ukolu \'$a\' bylo posouzeno';
$string['mail7'] = 'Komentare, kter uvedl $a, lze videt v zadani tohoto cviceni';
$string['managingassignment'] = 'Sprva cvien';
$string['maximum'] = 'Maximum';
$string['maximumgradeforstudentassessments'] = 'Nejvt mon poet bod za hodnocen studenty: $a';
$string['maximumgradeforsubmissions'] = 'Nejvt mon poet bod za een: $a';
$string['maximumsize'] = 'Nejvt mon velikost';
$string['mean'] = 'Prmr';
$string['minimum'] = 'Minimum';
$string['modulename'] = 'Cvien';
$string['modulenameplural'] = 'Cvien';
$string['movingtophase'] = 'Pechz se do fze $a';
$string['multiplesubmissions'] = 'Vcensobn een';
$string['noexercisedescriptionssubmitted'] = 'Nebyl podn dn popis cvien';
$string['nosubmissions'] = 'dn een';
$string['notassessedyet'] = 'Dosud nehodnoceno';
$string['notavailable'] = 'Nen k dispozici';
$string['noteonassessmentelements'] = 'Povimnte si, e bodovn je rozdleno do nkolika \"poloek hodnocen\".<br />Tm se doshne toho, e bodovn je snadnj a celistvj. Jako uitel muste pidat tyto <br />poloky  jet ped zpstupnnm kolu studentm. To udlte tak,<br />e kliknete na kol v kurzu - budete vyzvni k pidn<br />tchto poloek hodnocen. Jejich poet mete mnit na obrazovce Upravit kol,<br /> samy poloky mohou bt upraveny na strnce \"Sprva kol\".';
$string['noteongradinggrade'] = 'Tyto body jsou mtkem, jak dobe vae hodnocen souhlas s hodnocenm va prce, kter vypracoval $a. m vy je poet bod, tm jsou si hodnocen bli.';
$string['noteonstudentassessments'] = '{Body od studenta/Body za bodovn}';
$string['notgraded'] = 'Nebodovno';
$string['notitlegiven'] = 'Titulek neuveden';
$string['numberofassessmentelements'] = 'Poet koment, poloek hodnocen, bod, kritri nebo kategori v oddlu';
$string['numberofcriterionelements'] = 'Poet kritri mus bt vt ne jedno.';
$string['numberofentries'] = 'Poet poloek';
$string['numberofentriesinleaguetable'] = 'Poet poloek v ligov tabulce';
$string['numberofnegativeresponses'] = 'Poet zpornch odpovd';
$string['onesubmission'] = 'Jedno een';
$string['optionaladjustment'] = 'Voliteln nastaven';
$string['overallgrade'] = 'Celkov poet bod';
$string['passwordprotectedexercise'] = 'Heslem chrnn cvien';
$string['phase'] = 'Fze';
$string['phase1'] = 'Nastaven cvien';
$string['phase1short'] = 'Nastavit';
$string['phase2'] = 'Povolit hodnocen a odevzdvn pro $a';
$string['phase2short'] = 'Otevt';
$string['phase3'] = 'Ukzat celkov poet bod v ligov tabulce';
$string['phase3short'] = 'Zobrazit';
$string['pleasegradetheassessment'] = 'Prosm, obodujte hodnocen tto sti prce - zpracoval  $a';
$string['pleasemakeyourownassessment'] = 'Prosm, provete hodnocen een, kter vypracoval $a. <br />Povimnte si, e forma hodnocen je zpotku zobrazovna spolu s hodnocenm student. <br />Mli byste vloit dle vaeho mnn nezbytn nvrhy na zmny a pot kliknout na jedno z tlatek ve spodn sti strnky.';
$string['pleasesubmityourwork'] = 'Prosm, odevzdejte vai prci za pouit tohoto formule';
$string['pleaseusethisform'] = 'Prosm, vyplte tento formul, pokud jste<br />
dokonili instrukce v cvien uvedenm ne.';
$string['pleaseviewtheexercise'] = 'Prosm, zobrazte si cvien uveden ne kliknutm na jeho nzev.<br />
Postupujte podle instrukc v tomto cvien. Pokud si myslte,<br />
e jste cvien spn dokonili, kliknte na odkaz Hodnotit (nebo Pehodnotit) <br />
napravo od nzvu. A provedete toto hodnocen, dostanete instrukce,<br />
jak dle postupovat.';
$string['poor'] = 'Slab';
$string['present'] = 'Obsahuje';
$string['reasonforadjustment'] = 'Dvod pravy';
$string['reassess'] = 'Pehodnotit';
$string['regradestudentassessments'] = 'Pebodovat hodnocen student';
$string['resubmissionfor'] = 'Znovuodevzdn - $a';
$string['resubmitnote'] = '* znamen, e $a m povolen opakovan podn.<br />
Tento pznak me bt pidlen jakmukoli odevzdanmu kolu jeho  pehodnocenm a 
kliknutm na tlatko <b>Povolit pro $a znovuodevzdn</b>. <br />
Student me znovuodevzdat kol, kdy je tento pznak ptomen na <b>jakmkoli</b> z jeho odevzdanch kol.';
$string['rubric'] = 'Oddl';
$string['savedok'] = 'V podku uloeno';
$string['saveentries'] = 'Uloit poloky';
$string['savemyassessment'] = 'Uloit m hodnocen';
$string['saveweights'] = 'Uloit vhy';
$string['scale10'] = 'Poet bod z 10';
$string['scale100'] = 'Poet bod ze 100';
$string['scale20'] = 'Poet bod z 20';
$string['scalecorrect'] = '2 bodov stupnice Sprvn/Nesprvn';
$string['scaleexcellent4'] = '4 bodov stupnice Vborn/Velmi slab';
$string['scaleexcellent5'] = '5 bodov stupnice Vborn/Velmi slab';
$string['scaleexcellent7'] = '7 bodov stupnice Vborn/Velmi slab';
$string['scalegood3'] = '3 bodov stupnice Dobr/Slab';
$string['scalepresent'] = '2 bodov stupnice Obsahuje/Chyb';
$string['scaleyes'] = '2 bodov stupnice Ano/Ne';
$string['specimenassessmentform'] = 'Ukzkov formul hodnocen';
$string['standarddeviation'] = 'Smrodatn odchylka';
$string['strict'] = 'Pesn';
$string['studentallowedtoresubmit'] = '$a MٮE znovudevzdvat';
$string['studentassessments'] = '$a - hodnocen';
$string['studentnotallowed'] = '$a NEMٮE znovuodevzdvat';
$string['studentsubmissions'] = '$a Odevzdanch kol';
$string['studentsubmissionsforassessment'] = '$a Studenty odevzdan koly k hodnocen';
$string['submission'] = 'Odevzdan kol';
$string['submissions'] = 'Odevzdan koly';
$string['submissionsnowclosed'] = 'Termn uzvrky vyprel a odevzdvn vypracovanch kol je uzaveno';
$string['submitexercisedescription'] = 'Odeslat popis cvien';
$string['submitted'] = 'Odeslno';
$string['submittedby'] = 'Odeslal(a)';
$string['suggestedgrade'] = 'Navrhovan poet bod';
$string['teacherassessment'] = '$a - Hodnocen';
$string['teacherassessmenttable'] = '$a - Tabulka hodnocen';
$string['teacherscomment'] = 'Koment uitele';
$string['theexercise'] = 'Cvien';
$string['theexerciseandthesubmissionby'] = 'Cvien a odevzdan koly, kter zpracoval $a';
$string['thegradeis'] = 'Poet bod je $a';
$string['thereisfeedbackfromthe'] = 'Dola vyjden od: $a';
$string['thisisaresubmission'] = 'Toto je znovu odevzdn kol, kter vypracoval(a) $a.<br />
Je zobrazeno i vae hodnocen pedchozch odevzdn.<br />
Po prohldnut novho odevzdanho kolu doplte, prosm, toto hodnocen<br /> 
a kliknte na jedno z tlatek na dolnm okraji strnky.';
$string['title'] = 'Nzev';
$string['typeofscale'] = 'Typ kly';
$string['unassessed'] = '$a nehodnoceno';
$string['ungradedstudentassessments'] = '$a Nebodovanch studentskch hodnocen';
$string['usemaximum'] = 'Pout maximum';
$string['usemean'] = 'Pout prmr';
$string['usepassword'] = 'Pout heslo';
$string['verylax'] = 'Velmi nedbal';
$string['verypoor'] = 'Velmi slab';
$string['verystrict'] = 'Velmi pesn';
$string['view'] = 'Zobrazit';
$string['viewteacherassessment'] = 'Zobrazit $a hodnocen';
$string['warningonamendingelements'] = 'UPOZORNN: Bylo nalezeno odevzdan hodnocen<br />NEMTE poet poloek hodnocen, typ kly nebo vhu jednotlivch poloek.';
$string['weightederrorcount'] = 'Ven poet chyb: $a';
$string['weightforgradingofassessments'] = 'Vha pro bodovn hodnocen';
$string['weightforteacherassessments'] = 'Vha pro hodnocen od $a';
$string['weights'] = 'Vhy';
$string['weightssaved'] = 'Vhy uloeny';
$string['weightsusedforoverallgrade'] = 'Vhy pouit pro celkov bodovn';
$string['wrongpassword'] = 'Neplatn heslo k tomuto cvien';
$string['yourassessment'] = 'Vae hodnocen';
$string['yourfeedbackgoeshere'] = 'Vae vyjden pijde SEM';
$string['yoursubmission'] = 'Vae odevzdan koly';

?>

==> moodle-1.5.3.tgz: moodle/lang/cs/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.5 + (2005060201)


$string['absent'] = 'Chyb';
$string['accumulative'] = 'Nahromadn';
$string['action'] = 'Akce';
$string['ago'] = 'Ped $a';
$string['amend'] = 'Doplte';
$string['amendassessmentelements'] = 'Doplte poloky hodnocen';
$string['amendtitle'] = 'Doplte ';
$string['analysis'] = 'Rozbor';
$string['assess'] = 'Hodnotit';
$string['assessed'] = 'Hodnoceno';
$string['assessment'] = 'Hodnocen';
$string['assessmentby'] = 'Hodnoceno - $a';
$string['assessmentform'] = 'Hodnotc formul';
$string['assessmentmadebythe'] = 'Hodnocen provedl(a) $a';
$string['assessmentofthissubmission'] = 'Hodnocen tohoto odevzdanho kolu';
$string['assessments'] = 'Hodnocen';
$string['atthisstageyou'] = 'V tomto stdiu jste dokonili hodnocen.<br />
Na jeho zklad mete chtt svoji prci pepracovat.<br /> 
Pokud tak udlte, nezapomete tak upravit sv hodnocen.<br /> 
To mete provst kliknutm na odkaz Pehodnotit uveden ne.';
$string['awaitingassessmentbythe'] = 'ek se na hodnocen od $a';
$string['clearlateflag'] = 'Smazat pznak Zpodno';
$string['comment'] = 'Koment';
$string['comparisonofassessments'] = 'Srovnn hodnocen';
$string['confirmdeletionofthisitem'] = 'Potvrte odstrann tohoto $a';
$string['correct'] = 'Opravte';
$string['count'] = 'Poet';
$string['criterion'] = 'Kritrium';
$string['deadline'] = 'Uzvrka';
$string['deadlineis'] = 'Uzvrka je $a';
$string['delete'] = 'Odstranit';
$string['deletesubmissionwarning'] = 'Upozornn: toto een je ji hodnoceno ($a-krt).<br />Rozhodn vm jej doporuujeme NEODSTRAOVAT. ';
$string['deleting'] = 'Odstrauje se';
$string['description'] = 'Popis';
$string['descriptionofexercise'] = 'Pi zadvn kolu je popis cvien
nebo lohy, kter maj $a splnit, zadn ve Wordovskm dokumentu 
nebo HTML souboru. Tento soubor se zkopruje do cvien dve, ne maj
$a cvien zpstupnno. Je tak mono vytvoit sadu variant tho cvien 
nebo lohy, opt ve Wordu nebo v HTML a zkoprovat je do cvien pedtm, ne 
ho budou mt $a zpstupnno.';
$string['detailsofassessment'] = 'Podrobnosti hodnocen';
$string['displayoffinalgrades'] = 'Zobrazen konench znmek';
$string['doubleupload'] = 'Varovn: toto een bylo pravdpodobn poslno
dvakrt. Bte na strnku Sprvy a zjistte, zda tento uivatel
podal dv een v krtkm asovm intervalu. Dve ne budete pokraovat,
vymate jedno z tchto een.';
$string['duedate'] = 'Datum uzvrky';
$string['edit'] = 'Upravit';
$string['editingassessmentelements'] = 'prava poloek hodnocen';
$string['element'] = 'Poloka';
$string['elementweight'] = 'Vha poloky';
$string['enterpassword'] = 'Vlote heslo';
$string['entriessaved'] = 'Zznamy uloeny';
$string['errorbanded'] = 'Mnostv chyb';
$string['excellent'] = 'Vborn';
$string['exerciseassessments'] = 'Hodnocen cvien';
$string['exercisefeedback'] = 'Cvien - zptn vazba';
$string['exercisesubmissions'] = 'een';
$string['fair'] = 'Uspokojiv';
$string['generalcomment'] = 'Obecn koment';
$string['good'] = 'Dobr';
$string['gradeassessment'] = 'Bodov ohodnocen';
$string['gradeforassessment'] = 'Body pro hodnocen';
$string['gradeforstudentsassessment'] = 'Body za hodnocen, kter dlaj $a';
$string['gradeforsubmission'] = 'Body za een';
$string['gradetable'] = 'Bodov tabulka';
$string['gradinggrade'] = 'Body za bodovn';
$string['gradingstrategy'] = 'Bodovac strategie';
$string['handlingofmultiplesubmissions'] = 'Zpracovn vce een';
$string['hidenamesfromstudents'] = 'Skrt jmna ped studenty';
$string['incorrect'] = 'Nesprvn';
$string['late'] = 'Pozd';
$string['lax'] = 'Nedbal';
$string['leaguetable'] = 'Ligov tabulka odevzdanch prac';
$string['mail1'] = 'Vas ukol \'$a\' hodnotil ';
$string['mail2'] = 'Poznamky a body lze videt v zadani cviceni \'$a\'';
$string['mail3'] = 'Muzete jej videt v zadani ukolu vaseho cviceni';
$string['mail6'] = 'Vase hodnoceni ukolu \'$a\' bylo posouzeno';
$string['mail7'] = 'Komentare, kter uvedl $a, lze videt v zadani tohoto cviceni';
$string['managingassignment'] = 'Sprva cvien';
$string['maximum'] = 'Maximum';
$string['maximumgradeforstudentassessments'] = 'Nejvt mon poet bod za hodnocen studenty: $a';
$string['maximumgradeforsubmissions'] = 'Nejvt mon poet bod za een: $a';
$string['maximumsize'] = 'Nejvt mon velikost';
$string['mean'] = 'Prmr';
$string['minimum'] = 'Minimum';
$string['modulename'] = 'Cvien';
$string['modulenameplural'] = 'Cvien';
$string['movingtophase'] = 'Pechz se do fze $a';
$string['multiplesubmissions'] = 'Vcensobn een';
$string['noexercisedescriptionssubmitted'] = 'Nebyl podn dn popis cvien';
$string['nosubmissions'] = 'dn een';
$string['notassessedyet'] = 'Dosud nehodnoceno';
$string['notavailable'] = 'Nen k dispozici';
$string['noteonassessmentelements'] = 'Povimnte si, e bodovn je rozdleno do nkolika \"poloek hodnocen\".<br />Tm se doshne toho, e bodovn je snadnj a celistvj. Jako uitel muste pidat tyto <br />poloky  jet ped zpstupnnm kolu studentm. To udlte tak,<br />e kliknete na kol v kurzu - budete vyzvni k pidn<br />tchto poloek hodnocen. Jejich poet mete mnit na obrazovce Upravit kol,<br /> samy poloky mohou bt upraveny na strnce \"Sprva kol\".';
$string['noteongradinggrade'] = 'Tyto body jsou mtkem, jak dobe vae hodnocen souhlas s hodnocenm va prce, kter vypracoval $a. m vy je poet bod, tm jsou si hodnocen bli.';
$string['noteonstudentassessments'] = '{Body od studenta/Body za bodovn}';
$string['notgraded'] = 'Nebodovno';
$string['notitlegiven'] = 'Titulek neuveden';
$string['numberofassessmentelements'] = 'Poet koment, poloek hodnocen, bod, kritri nebo kategori v oddlu';
$string['numberofcriterionelements'] = 'Poet kritri mus bt vt ne jedno.';
$string['numberofentries'] = 'Poet poloek';
$string['numberofentriesinleaguetable'] = 'Poet poloek v ligov tabulce';
$string['numberofnegativeresponses'] = 'Poet zpornch odpovd';
$string['onesubmission'] = 'Jedno een';
$string['optionaladjustment'] = 'Voliteln nastaven';
$string['overallgrade'] = 'Celkov poet bod';
$string['passwordprotectedexercise'] = 'Heslem chrnn cvien';
$string['phase'] = 'Fze';
$string['phase1'] = 'Nastaven cvien';
$string['phase1short'] = 'Nastavit';
$string['phase2'] = 'Povolit hodnocen a odevzdvn pro $a';
$string['phase2short'] = 'Otevt';
$string['phase3'] = 'Ukzat celkov poet bod v ligov tabulce';
$string['phase3short'] = 'Zobrazit';
$string['pleasegradetheassessment'] = 'Prosm, obodujte hodnocen tto sti prce - zpracoval  $a';
$string['pleasemakeyourownassessment'] = 'Prosm, provete hodnocen een, kter vypracoval $a. <br />Povimnte si, e forma hodnocen je zpotku zobrazovna spolu s hodnocenm student. <br />Mli byste vloit dle vaeho mnn nezbytn nvrhy na zmny a pot kliknout na jedno z tlatek ve spodn sti strnky.';
$string['pleasesubmityourwork'] = 'Prosm, odevzdejte vai prci za pouit tohoto formule';
$string['pleaseusethisform'] = 'Prosm, vyplte tento formul, pokud jste<br />
dokonili instrukce v cvien uvedenm ne.';
$string['pleaseviewtheexercise'] = 'Prosm, zobrazte si cvien uveden ne kliknutm na jeho nzev.<br />
Postupujte podle instrukc v tomto cvien. Pokud si myslte,<br />
e jste cvien spn dokonili, kliknte na odkaz Hodnotit (nebo Pehodnotit) <br />
napravo od nzvu. A provedete toto hodnocen, dostanete instrukce,<br />
jak dle postupovat.';
$string['poor'] = 'Slab';
$string['present'] = 'Obsahuje';
$string['reasonforadjustment'] = 'Dvod pravy';
$string['reassess'] = 'Pehodnotit';
$string['regradestudentassessments'] = 'Pebodovat hodnocen student';
$string['resubmissionfor'] = 'Znovuodevzdn - $a';
$string['resubmitnote'] = '* znamen, e $a m povolen opakovan podn.<br />
Tento pznak me bt pidlen jakmukoli odevzdanmu kolu jeho  pehodnocenm a 
kliknutm na tlatko <b>Povolit pro $a znovuodevzdn</b>. <br />
Student me znovuodevzdat kol, kdy je tento pznak ptomen na <b>jakmkoli</b> z jeho odevzdanch kol.';
$string['rubric'] = 'Oddl';
$string['savedok'] = 'V podku uloeno';
$string['saveentries'] = 'Uloit poloky';
$string['savemyassessment'] = 'Uloit m hodnocen';
$string['saveweights'] = 'Uloit vhy';
$string['scale10'] = 'Poet bod z 10';
$string['scale100'] = 'Poet bod ze 100';
$string['scale20'] = 'Poet bod z 20';
$string['scalecorrect'] = '2 bodov stupnice Sprvn/Nesprvn';
$string['scaleexcellent4'] = '4 bodov stupnice Vborn/Velmi slab';
$string['scaleexcellent5'] = '5 bodov stupnice Vborn/Velmi slab';
$string['scaleexcellent7'] = '7 bodov stupnice Vborn/Velmi slab';
$string['scalegood3'] = '3 bodov stupnice Dobr/Slab';
$string['scalepresent'] = '2 bodov stupnice Obsahuje/Chyb';
$string['scaleyes'] = '2 bodov stupnice Ano/Ne';
$string['specimenassessmentform'] = 'Ukzkov formul hodnocen';
$string['standarddeviation'] = 'Smrodatn odchylka';
$string['strict'] = 'Pesn';
$string['studentallowedtoresubmit'] = '$a MٮE znovudevzdvat';
$string['studentassessments'] = '$a - hodnocen';
$string['studentnotallowed'] = '$a NEMٮE znovuodevzdvat';
$string['studentsubmissions'] = '$a Odevzdanch kol';
$string['studentsubmissionsforassessment'] = '$a Studenty odevzdan koly k hodnocen';
$string['submission'] = 'Odevzdan kol';
$string['submissions'] = 'Odevzdan koly';
$string['submissionsnowclosed'] = 'Termn uzvrky vyprel a odevzdvn vypracovanch kol je uzaveno';
$string['submitexercisedescription'] = 'Odeslat popis cvien';
$string['submitted'] = 'Odeslno';
$string['submittedby'] = 'Odeslal(a)';
$string['suggestedgrade'] = 'Navrhovan poet bod';
$string['teacherassessment'] = '$a - Hodnocen';
$string['teacherassessmenttable'] = '$a - Tabulka hodnocen';
$string['teacherscomment'] = 'Koment uitele';
$string['theexercise'] = 'Cvien';
$string['theexerciseandthesubmissionby'] = 'Cvien a odevzdan koly, kter zpracoval $a';
$string['thegradeis'] = 'Poet bod je $a';
$string['thereisfeedbackfromthe'] = 'Dola vyjden od: $a';
$string['thisisaresubmission'] = 'Toto je znovu odevzdn kol, kter vypracoval(a) $a.<br />
Je zobrazeno i vae hodnocen pedchozch odevzdn.<br />
Po prohldnut novho odevzdanho kolu doplte, prosm, toto hodnocen<br /> 
a kliknte na jedno z tlatek na dolnm okraji strnky.';
$string['title'] = 'Nzev';
$string['typeofscale'] = 'Typ kly';
$string['unassessed'] = '$a nehodnoceno';
$string['ungradedstudentassessments'] = '$a Nebodovanch studentskch hodnocen';
$string['usemaximum'] = 'Pout maximum';
$string['usemean'] = 'Pout prmr';
$string['usepassword'] = 'Pout heslo';
$string['verylax'] = 'Velmi nedbal';
$string['verypoor'] = 'Velmi slab';
$string['verystrict'] = 'Velmi pesn';
$string['view'] = 'Zobrazit';
$string['viewteacherassessment'] = 'Zobrazit $a hodnocen';
$string['warningonamendingelements'] = 'UPOZORNN: Bylo nalezeno odevzdan hodnocen<br />NEMTE poet poloek hodnocen, typ kly nebo vhu jednotlivch poloek.';
$string['weightederrorcount'] = 'Ven poet chyb: $a';
$string['weightforgradingofassessments'] = 'Vha pro bodovn hodnocen';
$string['weightforteacherassessments'] = 'Vha pro hodnocen od $a';
$string['weights'] = 'Vhy';
$string['weightssaved'] = 'Vhy uloeny';
$string['weightsusedforoverallgrade'] = 'Vhy pouit pro celkov bodovn';
$string['wrongpassword'] = 'Neplatn heslo k tomuto cvien';
$string['yourassessment'] = 'Vae hodnocen';
$string['yourfeedbackgoeshere'] = 'Vae vyjden pijde SEM';
$string['yoursubmission'] = 'Vae odevzdan koly';

?>
